@@ -4,7 +4,7 @@ try:
 except ImportError:
     # Try backported to PY<37 `importlib_resources`.
     import importlib_resources as pkg_resources
-from . import read_files
+import read_files
 
 def Flider():
     try:
@@ -18,7 +18,7 @@ def Flider():
         print('Continuing...')
     save_paths = ['flask_app/templates/', 'flask_app/config', 'flask_app/', 'flask_app/static/css/', 'flask_app/static/js/', '']
     file_names = ['index.html', 'mysqlcontroller.py', '__init__.py', 'style.css', 'scripts.js', 'server.py']
-    read_names = ['index.flid', 'mysqlcontroller.flid', '__init__.flid', 'style.flid', 'scripts.flid', 'server.flid']
+    read_names = ['index.flid', 'mysqlcontroller.flid', 'init.flid', 'style.flid', 'scripts.flid', 'server.flid']
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
